pub fn suggest_array_fix(schema: &Value) -> Option<Suggestion>Expand description
Suggest truncating an array that has too many items (E006 maxItems).
pub fn suggest_array_fix(schema: &Value) -> Option<Suggestion>Suggest truncating an array that has too many items (E006 maxItems).