pub fn suggest_string_fix(data: &str, schema: &Value) -> Option<Suggestion>Expand description
Suggest a truncation fix for a string that is too long (E004 maxLength).
pub fn suggest_string_fix(data: &str, schema: &Value) -> Option<Suggestion>Suggest a truncation fix for a string that is too long (E004 maxLength).